% This code computes the historical decomposition of the series 
%%%%      ---------Max Share with sign restriction---------      %%%%

clear all
close all
clc
delete *.asv

disp('Historical decomposition')

global VARMA H g1 JSpos JSneg srhpos srhneg

shock_type = 2;          % 1 = surprise tech, 2 = news
H = 80;                  % Truncation horizon
R = 2000;                % Number of bootstrap replications

rng('default');

bsdata = xlsread('news_shock_data.xlsx', 'data', 'B2:J192'); % BS data, 1960Q1 - 2007Q3
tfp = bsdata(:,1);
out = bsdata(:,2);
nds = bsdata(:,3);
hrs = bsdata(:,4);
sp = bsdata(:,5);
e5y = bsdata(:,6);
inff = bsdata(:,7);
dat1 = [tfp nds out hrs inff sp e5y]; 

% settings and initializations

[T,N] = size(dat1);
p = 3;
const = 1;
Impact = 0;
e1 = eye(N,1);
Ii = eye(N,1); 

opts = optimset('Display','off','Algorithm','sqp', 'MaxFunEval',10000,'MaxIter',20000, 'TolX',1e-16, 'Tolfun', 1e-16);

srhneg = {};
srhpos = {}; 

JSpos = 1;
srhpos{1} = 1:1;
JSneg = 5;
srhneg{1} = 1:10;

j = 1;
impvctr_MSSR = zeros(N,N,R);
CORRYYhat_MSSR = zeros(N,R);

while j <= R
    flag1 = -1;
    while flag1<1
        VARMA = VARIrband(VAREst(dat1, p, const), H, 0, Impact);
        A0 = (chol(VARMA.VARVCV,'lower'));
        B = VARMA.MAcoef;
        AA = squeeze(B(JSneg,:,srhneg{1}))'*A0;
        BB = zeros(size(srhneg{1},2),1);
        g10 = ones(N,1);
        [g1, ~, flag1] = fmincon(@IMP_Obj,g10,AA,BB,[],[],[],[],@cstr, opts); 
    end

    % News shock (zero impact on TFP & max share of TFP variance at long horizon & orthogonal to suprise shock
    flag2 = -10; 
    while flag2 < 1 
        Beq = zeros(2,1);
        Aeq = [g1'; squeeze(B(1,:,1))*A0];
        g20 = [0; randn(N-1,1)];
        [g2, ~, flag2] = fmincon(@MSObj,g20,[],[],Aeq,Beq,[],[],@cstr, opts);
    end

    if squeeze(B(1,:,H-30:H))'*A0*g2 < 0
        g2 = -g2;
    end

    D = eye(N);
    D(:,1:2) = [g1 g2];
%     impvctr(:,:,j) = D;
    shock = A0*D;
    
    if shock_type == 1
        select = [1];
    elseif shock_type == 2
        select = [2];
    elseif shock_type == 12
        select = [1 2];
    end 

    Hist_MSSR{j} = VARhistd2(VAREst(dat1, p, const),shock, select);

    clc
    disp(['Boostrap iteration: ', num2str(j)])
        
    j = j + 1;
end

save('HD_MSSR')
