clear all
close all
clc
delete *.asv

tic

disp('Empirical impulse responses')

global VARMA H

H = 80;         % Truncation horizon
R = 2000;       % Number of boostrap replications

rng('default')

bsdata = xlsread('news_shock_data.xlsx', 'data', 'B2:J192'); % BS data, 1960Q1 - 2007Q3
tfp = bsdata(:,1);
out = bsdata(:,2);
nds = bsdata(:,3);
hrs = bsdata(:,4);
sp = bsdata(:,5);
e5y = bsdata(:,6);
inff = bsdata(:,7);
dat1 = [tfp nds out hrs inff sp e5y];

p = 3;      
const = 1;
Impact = 0;
pct = 84;       % percentile for confidence interval
srhneg = {};
srhpos = {}; 
JSpos = 1;
srhpos{1} = 1:1;
JSneg = 5;
srhneg{1} = 1:10;
N = size(dat1,2);
g20 = [0; eye(N-1,1)];
IRS = zeros(N,H+1,R);
IRN = zeros(N,H+1,R);
FEVD = zeros(N,2,H+1,R);
opts = optimset('Display','off','Algorithm','sqp', 'MaxFunEval',20000,'MaxIter',20000, 'TolX',1e-16, 'Tolfun', 1e-16);

j = 1;
while j <= R
        % Surprise technology shock (Max share of TFP variance on impact & negative inflation response)
        flag1 = -10;
        while flag1 < 1 
            VARMA = VARIrband(VAREst(dat1, p, const), H, 0, Impact);
            A0 = (chol(VARMA.VARVCV,'lower')); 
            B = VARMA.MAcoef;
            AA = squeeze(B(JSneg,:,srhneg{1}))'*A0;
            BB = zeros(size(srhneg{1},2),1);
            g10 = ones(N,1);
            [g1, ~, flag1] = fmincon(@IMP_Obj,g10,AA,BB,[],[],[],[],@cstr, opts); 

        end

        % News shock (zero impact on TFP & max share of TFP variance at long horizon & orthogonal to suprise shock
        flag2 = -10; 
        while flag2 < 1 
            Beq = zeros(2,1);
            Aeq = [g1'; squeeze(B(1,:,1))*A0];
            g20 = [0; randn(N-1,1)];
            [g2, ~, flag2] = fmincon(@MSObj,g20,[],[],Aeq,Beq,[],[],@cstr, opts);

        end

             if squeeze(B(1,:,H-30:H))'*A0*g2 < 0;
                g2 = -g2;
             end

        for i = 1:N
            for h = 0:H
                IRS(i,h+1,j) = B(i,:,h+1)*A0*g1;
                IRN(i,h+1,j) = B(i,:,h+1)*A0*g2;
            end

        end

    FEVD(:,:,:,j) = Vardecomp(VARMA, H, [g1 g2]);

    clc
    disp(['Boostrap iteration: ', num2str(j)]) 

    j = j+1;


 end


Sband_MSSR = prctile(squeeze(IRS),[50 100-pct pct],3);
Nband_MSSR = prctile(squeeze(IRN),[50 100-pct pct],3);

% Forecast Error Variance Decomposition
FEVD = prctile(squeeze(FEVD),[50 100-pct pct],4);
hor = [1 4 8 16 24 40];
NVD_MSSR = squeeze(FEVD(:, 2, hor,1));
NVD_MSSR = [NVD_MSSR; (squeeze(FEVD(1, 1, hor,1)) + squeeze(FEVD(1, 2, hor,1)))'; (squeeze(FEVD(3, 1, hor,1)) + squeeze(FEVD(3, 2, hor,1)))'];
SVD_MSSR = squeeze(FEVD(:, 1, hor,1));

    
save('Irf_VD_MSSR')

% toc