clear all
close all
clc
delete *.asv

load Irf_VD_BS.mat;             % Barsky and Sims' Strategy applied to our  sample (1960Q1 - 2019Q4)
load SW_BS.mat;                 % irfs from SW model calibrated to match the TFP response based on BS strategy
load NK.mat;                    % irfs from the standard NK model


vars = ['TFP           '; ['Consumption', '   ']; 'Output        '; 'Hours         '; 'Inflation     '; ['Stock Prices', '  ']; 'Confidence    '];

xinfl = 0:7;                    % horizons at which the inflation response is restricted to be negative
h = 41;                         % h-1 is the number of priods in graphs
t = 0:h-1;


disp('Impulse responses to a surprise technology shock')
figure(1) 
subplot(3,3,1);shadedErrorBar(t,100*squeeze(Sband_BS(1,1:h,1)),100*[squeeze(Sband_BS(1,1:h,3)); squeeze(Sband_BS(1,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Adjusted TFP', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'Box','on','fontsize', 7);set(gcf,'Renderer','Painters');ylabel('Percent','fontsize', 6)
hold on
plot(t,at_a(1:h),':g','LineWidth',1.5);
hold on
plot(t,atsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

subplot(3,3,2);shadedErrorBar(t,100*squeeze(Sband_BS(2,1:h,1)),100*[squeeze(Sband_BS(2,1:h,3)); squeeze(Sband_BS(2,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Consumption', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'Box','on','fontsize', 7);set(gcf,'Renderer','Painters');ylabel('Percent','fontsize', 6)
hold on
plot(t,ct_a(1:h),':g','LineWidth',1.5);
hold on
plot(t,ctsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

subplot(3,3,3);shadedErrorBar(t,100*squeeze(Sband_BS(3,1:h,1)),100*[squeeze(Sband_BS(3,1:h,3)); squeeze(Sband_BS(3,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Output', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'Box','on','fontsize', 7);set(gcf,'Renderer','Painters');ylabel('Percent','fontsize', 6)
hold on
plot(t,yt_a(1:h),':g','LineWidth',1.5);
hold on
plot(t,ytsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
legend({'Confidence Bands','Estimated IRFs','Basic NK Model', 'SW Model'},'Location','northeast', 'Fontsize', 4)
hold off

subplot(3,3,4);shadedErrorBar(t,100*squeeze(Sband_BS(4,1:h,1)),100*[squeeze(Sband_BS(4,1:h,3)); squeeze(Sband_BS(4,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Hours', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'Box','on','fontsize', 7);set(gcf,'Renderer','Painters');ylabel('Percent','fontsize', 6)
hold on
plot(t,nt_a(1:h),':g','LineWidth',1.5);
hold on
plot(t,ntsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

subplot(3,3,5);shadedErrorBar(t,100*squeeze(Sband_BS(5,1:h,1)),100*[squeeze(Sband_BS(5,1:h,3)); squeeze(Sband_BS(5,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Inflation', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'Box','on','fontsize', 7);set(gcf,'Renderer','Painters');ylabel('Percentage Points', 'fontsize', 6)
hold on
plot(t,pit_a(1:h),':g','LineWidth',1.5);
hold on
plot(t,pitsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

subplot(3,3,6);shadedErrorBar(t,100*squeeze(Sband_BS(6,1:h,1)),100*[squeeze(Sband_BS(6,1:h,3)); squeeze(Sband_BS(6,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Stock Prices', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'Box','on','fontsize', 7);set(gcf,'Renderer','Painters');ylabel('Percent', 'fontsize', 6)
hold on
plot(t, zeros(size(t)),'-k')
hold off

subplot(3,3,7);shadedErrorBar(t,squeeze(Sband_BS(7,1:h,1)),[squeeze(Sband_BS(7,1:h,3)); squeeze(Sband_BS(7,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Confidence', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'Box','on','fontsize', 7);set(gcf,'Renderer','Painters');ylabel('Points', 'fontsize', 6)
hold on
plot(t, zeros(size(t)),'-k')
hold off
