clear all
close all
clc
delete *.asv

load Irf_VD_BS.mat;             % Barsky and Sims' Strategy applied to extended  sample (1960Q1 - 2019Q4)
load Irf_VD_MS.mat;             % Max Share applied to extended sample (1960Q1 - 2019Q4)
load Irf_VD_MSSR.mat;           % Agnostic Strategy with BS criterion applied to extended sample (1960Q1 - 2019Q4)

load SW_BS.mat;                 % irfs from SW model calibrated to match the TFP response based on BS strategy
load SW_MS.mat;                 % irfs from SW model calibrated to match the TFP response based on MS strategy
load SW_MSSR.mat;               % irfs from SW model calibrated to match the TFP response based on the agnostic strategy


vars = ['TFP           '; ['Consumption', '   ']; 'Output        '; 'Hours         '; 'Inflation     '; ['Stock Prices', '  ']; 'Confidence    '];

xinfl = 0:9;                    % horizons at which the inflation response is restricted to be negative
h = 41;                         % h-1 is the number of priods in graphs
t = 0:h-1;


disp('Empirical impulse responses...');
figure(1) % Surprise technology
y1 = [-0.002 0.008];
subplot(7,2,1);shadedErrorBar(t,100*squeeze(Sband_BS(1,1:h,1)),[100*squeeze(Sband_BS(1,1:h,3)); 100*squeeze(Sband_BS(1,1:h,2))],{'-k', 'LineWidth',1.5},0)
title({'\fontsize{9}{Reduced-Form Innovation to TFP}','','\fontsize{7}Adjusted TFP'}, 'FontWeight', 'normal', 'fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,atsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,2,2);shadedErrorBar(t,100*squeeze(Sband_MSSR(1,1:h,1)),[100*squeeze(Sband_MSSR(1,1:h,3)); 100*squeeze(Sband_MSSR(1,1:h,2))],{'-b', 'LineWidth',1.5},0)
title({'\fontsize{9}Agnostic Approach','','\fontsize{7}Adjusted TFP'},'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,atsw_MSSR_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
legend({'Confidence Bands','Estimated IRFs','SW Model'}, 'FontSize', 4, 'Location', 'northeast');
hold off

y1 = [-0.005 0.007];
subplot(7,2,3);shadedErrorBar(t,100*squeeze(Sband_BS(2,1:h,1)),[100*squeeze(Sband_BS(2,1:h,3)); 100*squeeze(Sband_BS(2,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Consumption','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ctsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,2,4);shadedErrorBar(t,100*squeeze(Sband_MSSR(2,1:h,1)),[100*squeeze(Sband_MSSR(2,1:h,3)); 100*squeeze(Sband_MSSR(2,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Consumption','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ctsw_MSSR_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-0.005 0.01];
subplot(7,2,5);shadedErrorBar(t,100*squeeze(Sband_BS(3,1:h,1)),[100*squeeze(Sband_BS(3,1:h,3)); 100*squeeze(Sband_BS(3,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Output','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ytsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,2,6);shadedErrorBar(t,100*squeeze(Sband_MSSR(3,1:h,1)),[100*squeeze(Sband_MSSR(3,1:h,3)); 100*squeeze(Sband_MSSR(3,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Output','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ytsw_MSSR_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-0.007 0.007];
subplot(7,2,7);shadedErrorBar(t,100*squeeze(Sband_BS(4,1:h,1)),[100*squeeze(Sband_BS(4,1:h,3)); 100*squeeze(Sband_BS(4,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Hours','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);
set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ntsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,2,8);shadedErrorBar(t,100*squeeze(Sband_MSSR(4,1:h,1)),[100*squeeze(Sband_MSSR(4,1:h,3)); 100*squeeze(Sband_MSSR(4,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Hours','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ntsw_MSSR_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-0.25 0.15];
subplot(7,2,9);shadedErrorBar(t,100*squeeze(Sband_BS(5,1:h,1)),100*[squeeze(Sband_BS(5,1:h,3)); squeeze(Sband_BS(5,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Inflation','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percentage Points')
hold on
plot(t,pitsw_BS_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,2,10);shadedErrorBar(xinfl,[], repmat(y1,length(xinfl),1),{'-r', 'LineWidth',1},0);set(gcf,'Renderer','Painters')
title('Inflation','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percentage Points')
hold on
shadedErrorBar(t,100*squeeze(Sband_MSSR(5,1:h,1)),100*[squeeze(Sband_MSSR(5,1:h,3)); squeeze(Sband_MSSR(5,1:h,2))],{'-b', 'LineWidth',1.5},0)
hold on
plot(t,pitsw_MSSR_a(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-0.04 0.04];
subplot(7,2,11);shadedErrorBar(t,100*squeeze(Sband_BS(6,1:h,1)),[100*squeeze(Sband_BS(6,1:h,3)); 100*squeeze(Sband_BS(6,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Stock Prices','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,2,12);shadedErrorBar(t,100*squeeze(Sband_MSSR(6,1:h,1)),[100*squeeze(Sband_MSSR(6,1:h,3)); 100*squeeze(Sband_MSSR(6,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Stock Prices','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-2.5 4];
subplot(7,2,13);shadedErrorBar(t,squeeze(Sband_BS(7,1:h,1)),[squeeze(Sband_BS(7,1:h,3)); squeeze(Sband_BS(7,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Confidence','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('points')
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,2,14);shadedErrorBar(t,squeeze(Sband_MSSR(7,1:h,1)),[squeeze(Sband_MSSR(7,1:h,3)); squeeze(Sband_MSSR(7,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Confidence','FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('points')
hold on
plot(t, zeros(size(t)),'-k')
hold off

fig = gcf;
fig.PaperPositionMode = 'auto';
print(gcf,'-dpdf','Irfs_Surp_2019','-fillpage');

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
figure(2) % News
    
y1 = [-0.002 0.007];
subplot(7,3,1);shadedErrorBar(t,100*squeeze(Nband_BS(1,1:h,1)),[100*squeeze(Nband_BS(1,1:h,3)); 100*squeeze(Nband_BS(1,1:h,2))],{'-k', 'LineWidth',1.5},0)
title({'\fontsize{9}{Barsky & Sims'' Approach}','','\fontsize{7}Adjusted TFP'}, 'FontWeight', 'normal', 'fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,atsw_BS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,2);shadedErrorBar(t,100*squeeze(Nband_MS(1,1:h,1)),[100*squeeze(Nband_MS(1,1:h,3)); 100*squeeze(Nband_MS(1,1:h,2))],{'-k', 'LineWidth',1.5},0)
title({'\fontsize{9}{Max Share Approach}','','\fontsize{7}Adjusted TFP'}, 'FontWeight', 'normal', 'fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,atsw_MS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
p1 = subplot(7,3,3);shadedErrorBar(t,100*squeeze(Nband_MSSR(1,1:h,1)),[100*squeeze(Nband_MSSR(1,1:h,3)); 100*squeeze(Nband_MSSR(1,1:h,2))],{'-b', 'LineWidth',1.5},0)
title({'\fontsize{9}{Agnostic Approach}','','\fontsize{7}Adjusted TFP'}, 'FontWeight', 'normal', 'fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,atsw_MSSR_n(1:h),'--r','LineWidth',1.5);
plot(t, zeros(size(t)),'-k')
legend(p1, {'Confidence Bands','Estimated IRFs','SW Model'}, 'FontSize', 4, 'Location', 'northeast');
hold off


y1 = [-0.0025 0.01];
subplot(7,3,4);shadedErrorBar(t,100*squeeze(Nband_BS(2,1:h,1)),[100*squeeze(Nband_BS(2,1:h,3)); 100*squeeze(Nband_BS(2,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Consumption', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ctsw_BS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,5);shadedErrorBar(t,100*squeeze(Nband_MS(2,1:h,1)),[100*squeeze(Nband_MS(2,1:h,3)); 100*squeeze(Nband_MS(2,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Consumption', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ctsw_MS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,6);shadedErrorBar(t,100*squeeze(Nband_MSSR(2,1:h,1)),[100*squeeze(Nband_MSSR(2,1:h,3)); 100*squeeze(Nband_MSSR(2,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Consumption', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ctsw_MSSR_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-0.005 0.015];
subplot(7,3,7);shadedErrorBar(t,100*squeeze(Nband_BS(3,1:h,1)),[100*squeeze(Nband_BS(3,1:h,3)); 100*squeeze(Nband_BS(3,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Output', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ytsw_BS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,8);shadedErrorBar(t,100*squeeze(Nband_MS(3,1:h,1)),[100*squeeze(Nband_MS(3,1:h,3)); 100*squeeze(Nband_MS(3,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Output', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ytsw_MS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,9);shadedErrorBar(t,100*squeeze(Nband_MSSR(3,1:h,1)),[100*squeeze(Nband_MSSR(3,1:h,3)); 100*squeeze(Nband_MSSR(3,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Output', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ytsw_MSSR_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-0.007 0.010];
subplot(7,3,10);shadedErrorBar(t,100*squeeze(Nband_BS(4,1:h,1)),[100*squeeze(Nband_BS(4,1:h,3)); 100*squeeze(Nband_BS(4,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Hours', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ntsw_BS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,11);shadedErrorBar(t,100*squeeze(Nband_MS(4,1:h,1)),[100*squeeze(Nband_MS(4,1:h,3)); 100*squeeze(Nband_MS(4,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Hours', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ntsw_MS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,12);shadedErrorBar(t,100*squeeze(Nband_MSSR(4,1:h,1)),[100*squeeze(Nband_MSSR(4,1:h,3)); 100*squeeze(Nband_MSSR(4,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Hours', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t,ntsw_MSSR_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-0.4 0.15];
subplot(7,3,13);shadedErrorBar(t,100*squeeze(Nband_BS(5,1:h,1)),100*[squeeze(Nband_BS(5,1:h,3)); squeeze(Nband_BS(5,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Inflation', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percentage Points')
hold on
plot(t,pitsw_BS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,14);shadedErrorBar(t,100*squeeze(Nband_MS(5,1:h,1)),100*[squeeze(Nband_MS(5,1:h,3)); squeeze(Nband_MS(5,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Inflation', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percentage Points')
hold on
plot(t,pitsw_MS_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,15);shadedErrorBar(t,100*squeeze(Nband_MSSR(5,1:h,1)),100*[squeeze(Nband_MSSR(5,1:h,3)); squeeze(Nband_MSSR(5,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Inflation', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percentage Points')
hold on
plot(t,pitsw_MSSR_n(1:h),'--r','LineWidth',1.5);
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-0.03 0.055];
subplot(7,3,16);shadedErrorBar(t,100*squeeze(Nband_BS(6,1:h,1)),[100*squeeze(Nband_BS(6,1:h,3)); 100*squeeze(Nband_BS(6,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Stock Prices', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,17);shadedErrorBar(t,100*squeeze(Nband_MS(6,1:h,1)),[100*squeeze(Nband_MS(6,1:h,3)); 100*squeeze(Nband_MS(6,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Stock Prices', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,18);shadedErrorBar(t,100*squeeze(Nband_MSSR(6,1:h,1)),[100*squeeze(Nband_MSSR(6,1:h,3)); 100*squeeze(Nband_MSSR(6,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Stock Prices', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', 100*y1, 'Box','on', 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('Percent')
hold on
plot(t, zeros(size(t)),'-k')
hold off

y1 = [-2 6];
subplot(7,3,19);shadedErrorBar(t,squeeze(Nband_BS(7,1:h,1)),[squeeze(Nband_BS(7,1:h,3)); squeeze(Nband_BS(7,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Confidence', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('points')
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,20);shadedErrorBar(t,squeeze(Nband_MS(7,1:h,1)),[squeeze(Nband_MS(7,1:h,3)); squeeze(Nband_MS(7,1:h,2))],{'-k', 'LineWidth',1.5},0)
title('Confidence', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('points')
hold on
plot(t, zeros(size(t)),'-k')
hold off
subplot(7,3,21);shadedErrorBar(t,squeeze(Nband_MSSR(7,1:h,1)),[squeeze(Nband_MSSR(7,1:h,3)); squeeze(Nband_MSSR(7,1:h,2))],{'-b', 'LineWidth',1.5},0)
title('Confidence', 'FontWeight', 'normal','fontsize', 7);set(gca,'XTick',5:5:H, 'ylim', y1, 'Box','on','FontSize',7);set(gcf,'Renderer','Painters');ylabel('points')
hold on
plot(t, zeros(size(t)),'-k')
hold off

fig = gcf;
fig.PaperPositionMode = 'auto';
print(gcf,'-dpdf','Irfs_News_2019','-fillpage');
    
disp('                                                                                   ');
disp('Variance Decomposition: Barsky & Sims')
disp('                                                                                   ');
disp('Table 1: Contribution of the surprise technology shock                             ');
disp('===================================================================================');
disp('    Horizon      1           4           8          16          24          40     ');
disp('Variables                                                                          ');
disp('===================================================================================');
disp([vars, num2str(decimals(SVD_BS, 4))])
disp('===================================================================================');
disp('                                                                                   ');
disp('                                                                                   ');
disp('                                                                                   ');
disp('Table 2: Contribution of the news shock                                            ');
disp('===================================================================================');
disp('    Horizon      1           4           8          16          24          40     ');
disp('Variables                                                                          ');
disp('===================================================================================');
disp([[vars; 'Total TFP     ';'Total output  ' ], num2str(decimals(NVD_BS, 4))])
disp('===================================================================================');
disp('                                                                                   ');

disp('                                                                                   ');
disp('Variance Decomposition: Max Share')
disp('                                                                                   ');
disp('Table 1: Contribution of the surprise technology shock                             ');
disp('===================================================================================');
disp('    Horizon      1           4           8          16          24          40     ');
disp('Variables                                                                          ');
disp('===================================================================================');
disp([vars, num2str(decimals(SVD_MS, 4))])
disp('===================================================================================');
disp('                                                                                   ');
disp('                                                                                   ');
disp('                                                                                   ');
disp('Table 2: Contribution of the news shock                                            ');
disp('===================================================================================');
disp('    Horizon      1           4           8          16          24          40     ');
disp('Variables                                                                          ');
disp('===================================================================================');
disp([[vars; 'Total TFP     ';'Total output  ' ], num2str(decimals(NVD_MS, 4))])
disp('===================================================================================');
disp('                                                                                   ');


disp('                                                                                   ');
disp('Variance Decomposition: Agnostic Approach')
disp('                                                                                   ');
disp('Table 1: Contribution of the surprise technology shock                             ');
disp('===================================================================================');
disp('    Horizon      1           4           8          16          24          40     ');
disp('Variables                                                                          ');
disp('===================================================================================');
disp([vars, num2str(decimals(SVD_MSSR, 4))])
disp('===================================================================================');
disp('                                                                                   ');
disp('                                                                                   ');
disp('                                                                                   ');
disp('Table 2: Contribution of the news shock                                            ');
disp('===================================================================================');
disp('    Horizon      1           4           8          16          24          40     ');
disp('Variables                                                                          ');
disp('===================================================================================');
disp([[vars; 'Total TFP     ';'Total output  ' ], num2str(decimals(NVD_MSSR, 4))])
disp('===================================================================================');
disp('                                                                                   ');
