clear all
close all
clc

disp('Empirical impulse responses and Variance decomposition')

global VARMA H 

H = 80;             % Truncation horizon
opt = 2;            % 1 for numerical optimization and other for analytical solution
R = 2000;           % Number of boostrap replications

rng('default');

% data

bsdata = xlsread('newsdata2019.xlsx', 'Data'); % Our data, 1960Q1 - 2019Q4
tfp = bsdata(:,2);
out = bsdata(:,3);
nds = bsdata(:,4);
hrs = bsdata(:,5);
sp = bsdata(:,6);
e5y = bsdata(:,7);
inff = bsdata(:,8);
dat2 = [tfp nds out hrs inff sp e5y];

% settings and initializations
N = size(dat2,2);
p = 3;
const = 1;
Impact = 0;
pct = 84; % percentile for confidence interval
IRS = zeros(N,H+1,R);
IRN = zeros(N,H+1,R);
N = size(dat2,2);
g20 = [0; eye(N-1,1)];
Aeq = eye(1,N);
Beq = 0;
FEVD = zeros(N,2,H+1,R);
opts = optimset('Display','off','Algorithm','sqp', 'MaxFunEval',20000,'MaxIter',20000, 'TolX',1e-16, 'Tolfun', 1e-16);


% Estimations
j = 1;
while j <= R
    if opt == 1
        flags = -10;
        while flags <=0
            VARMA = VARIrband(VAREst(dat2, p, const), H, 0, Impact);
            A0 = (chol(VARMA.VARVCV,'lower'));
            B = VARMA.MAcoef;
            g20 = ones(N,1);
            [gs, ~, flags] = fmincon(@MSObj,g20,[],[],Aeq,Beq,[],[],@cstr);
        end

        if squeeze(B(1,:,20:H))'*A0*gs < 0; % makes sure that TFP responds positively to news
           gs = -gs;
        end
    else
        VARMA = VARIrband(VAREst(dat2, p, const), H, 0, Impact);
        A0 = (chol(VARMA.VARVCV,'lower'));
        B = VARMA.MAcoef;
        SIG = A0*A0';
        e1 = eye(N,1);
        
        Fmat = zeros(N,N);
        Num = zeros(N,N);
        Denom = 0;
        for t = 0:H
            Num = Num + (e1'*(B(:,:,t+1)*A0))'*(e1'*(B(:,:,t+1)*A0));
            Denom = Denom + e1'*(B(:,:,t+1)*SIG*B(:,:,t+1)')*e1;
        end
        Fmat = Fmat + Num/Denom;
        [V,D] = eig(Fmat(2:end,2:end));
        [~,I] = max(abs(diag(D)));
        gs = [0; -V(:,I)];

        if ~(squeeze(B(1,:,20:H))'*A0*gs >= 0) % makes sure that TFP responds positively to news
            gs = -gs;
        end 

    end

    B1 = VARMA.IRFs;

    for i = 1:N
        for h = 0:H
            IRN(i,h+1,j) = B(i,:,h+1)*A0*gs;
            IRS(i,h+1,j) = B1(i,:,h+1)*A0*eye(N,1);
        end
    end
     [~, FEVD(:,:,:,j)] = BSObj2(gs);
    if mod(j,25) == 0
        clc
        disp(['Boostrap iteration: ', num2str(round(j*100/R)), '% complete ...'])
    end 
    j = j+1;
end
   
Nband_MS = prctile(squeeze(IRN),[50 100-pct pct],3);
Sband_MS = prctile(squeeze(IRS),[50 100-pct pct],3);

% Forecast Error Variance Decomposition
FEVD = prctile(squeeze(FEVD),[50 100-pct pct],4);
hor = [1 4 8 16 24 40];
NVD_MS = squeeze(FEVD(:, 2, hor,1));
NVD_MS = [NVD_MS; (squeeze(FEVD(1, 1, hor,1)) + squeeze(FEVD(1, 2, hor,1)))'; (squeeze(FEVD(3, 1, hor,1)) + squeeze(FEVD(3, 2, hor,1)))'];
SVD_MS = squeeze(FEVD(:, 1, hor,1));
    
save('Irf_VD_MS')
        
 
    
    
