
% This code computes historical decomposition form a VAR 

% Input
% VAR[struct]: Estimates form VAREst 
% shock[matrix] (optional): Matrix of structural impulse vectors (submatrix of orthonormal matrix) to be used; 
        % If not specified, the reduced-form innovations are used (original data are recovered);
        % For identified structural shocks, this should be such that
        % Resid*shock gives the series of structural shocks of interest
        % completed by series of zeros in the positions of shocks that are
        % not of interest. If Resid*shock gives all the structural shocks,
        % the original data are recovered.

% Output
% out.data: initial data VAR used to perform the VAR
% out.histdcmp: historical decomposition
% out.hdresid: structural shocks used


function Out = VARhistd2(VAR, shock, select)
T = VAR.nobs;
p = VAR.lag;
N = VAR.nvars;
Y = VAR.data;
EST = VAR.Coef;
resid = VAR.Residuals;
Out.data = Y;


if nargin < 2
    shock = eye(N);
end

if nargin < 3
    select = 1:N;
end

strresid = resid/shock';

hdresid = zeros(size(resid));
hdresid(:,select) = strresid(:,select);


Out.hdresid = hdresid;

XX = [];
for i = 1:p
    XX = [Y(i,:) XX];
end

histdcmp = zeros(T-p,N);
for j = 1:T-p
    ct = []; %constant components
    if VAR.Constant == 1
        ct = [ct 1];
    end
    shk = shock*hdresid(j,:)';
    for k = 1:N
        histdcmp(j,k) = [ct XX]*EST(k,:)' + shk(k);
    end
    XX = [histdcmp(j,:) XX(1:end-N)];
end

Out.histdcmp = histdcmp;
