clear all;
close all;

rng('default')

dynare NK_CRS
irfs = oo_.irfs;
XSim = oo_.endo_simul;
close all

irf_a = irfs.atilde_ea;
irf_y = irfs.y_ea;
irf_pi = irfs.pi_ea;

irf_an = irfs.atilde_en;
irf_yn = irfs.y_en;
irf_pin = irfs.pi_en;

XSim = XSim';
NSim = size(XSim);

global VARMA H

% settings and initializations
RR = 3500; % Number of dynare simulations 
R = 2000; % Number of replications used for IRFs below
N = 3;
p = 1;
H = 40;
const = 0;
Impact = 0;
pct = 84; % percentile for confidence interval
IRSURP = zeros(N,H+1,R);
IRNEWS = zeros(N,H+1,R);
FEVD = zeros(N,2,H+1,R);

options_ = struct('periods', NSim(1), 'simul_replic', RR);
sim_array = get_simul_replications(M_,options_);

hh = H;

ii = 1;
j = 1;
while j <= R && ii <= RR
    
    atilde = sim_array(1, 1:NSim, ii);
    y = sim_array(2, 1:NSim, ii);
    pi = sim_array(3, 1:NSim, ii);
    YY4 = [atilde; y; pi]'; 

    % Estimations

    VARMA = VARIrband(VAREst(YY4, p, const), H, 1, Impact);
    A0 = (chol(VARMA.VARVCV,'lower'));
    B = VARMA.MAcoef;
    SIG = A0*A0';
    e1 = eye(N,1);

    % News shock (zero impact on TFP & max share of TFP variance at long horizon & orthogonal to suprise shock

    Fmat = zeros(N,N);
    for h = hh:H
        Num = zeros(N,N);
        Denom = 0;
        for t = 0:h
            Num = Num + (e1'*(B(:,:,t+1)*A0))'*(e1'*(B(:,:,t+1)*A0));
            Denom = Denom + e1'*(B(:,:,t+1)*SIG*B(:,:,t+1)')*e1;
        end
        Fmat = Fmat + Num/Denom;
    end
    [V,D] = eig(Fmat(2:end,2:end));
    [~,I] = max(abs(diag(D)));
    gs = [0; -V(:,I)];


    if squeeze(B(1,:,H-30:H+1))'*A0*gs > 0  % makes sure that TFP responds positively to news
        for i = 1:N
            for h = 0:H
                IRSURP(i,h+1,j) = B(i,:,h+1)*A0*e1;
                IRNEWS(i,h+1,j) = B(i,:,h+1)*A0*gs;
            end
        end

        if mod(j,25) == 0
            %clc
            disp(['Bootstrap iteration: ', num2str(round(j*100/R)), '% complete ...'])
        end 

        FEVD(:,:,:,j) = Vardecomp(VARMA, H, [e1 gs]);
        j = j+1;
    elseif (squeeze(B(1,:,H-30:H+1))'*A0*gs < 0)  % makes sure that TFP responds positively to news
        gs = -gs;
        for i = 1:N
            for h = 0:H
                IRSURP(i,h+1,j) = B(i,:,h+1)*A0*e1;
                IRNEWS(i,h+1,j) = B(i,:,h+1)*A0*gs;
            end
        end


        if mod(j,25) == 0
            %clc
            disp(['Bootstrap iteration: ', num2str(round(j*100/R)), '% complete ...'])
        end 
        
        FEVD(:,:,:,j) = Vardecomp(VARMA, H, [e1 gs]);
        j = j+1;
    end 
        
     ii = ii+1;

end


%%
SCRS_BS = prctile(squeeze(IRSURP),[50 100-pct pct],3);
NCRS_BS = prctile(squeeze(IRNEWS),[50 100-pct pct],3);

% Forecast Error Variance Decomposition
FEVD_CRS = prctile(squeeze(FEVD),[50 100-pct pct],4);
save(['Sim_data_CRS_BS.mat'])





