clear all;
close all;

rng('default')

dynare NK_IRS
irfs = oo_.irfs;
XSim = oo_.endo_simul;
close all

irf2_a = irfs.atilde_ea;
irf2_y = irfs.y_ea;
irf2_pi = irfs.pi_ea;

irf2_an = irfs.atilde_en;
irf2_yn = irfs.y_en;
irf2_pin = irfs.pi_en;

XSim = XSim';
NSim = size(XSim);

global VARMA H

% settings and initializations
RR = 3500; % Number of dynare simulations 
R = 2000; % Number of replications used for IRFs below
N = 3;
p = 1;
H = 80;
const = 0;
Impact = 0;
pct = 84; % percentile for confidence interval
srhneg = {};
srhpos = {}; 
JSpos = 1;
srhpos{1} = 1:1;
JSneg = 3;
srhneg{1} = 1:10;
IRSURP = zeros(N,H+1,R);
IRNEWS = zeros(N,H+1,R);
FEVD = zeros(N,2,H+1,R);
opts = optimset('Display','off','Algorithm','interior-point', 'MaxFunEval',20000,'MaxIter',200000, 'TolX',1e-18, 'Tolfun', 1e-18);

options_ = struct('periods', NSim(1), 'simul_replic', RR);
sim_array = get_simul_replications(M_,options_);

ii = 1;
j = 1;
while j <= R && ii <= RR
    
    atilde = sim_array(1, 1:NSim, ii);
    y = sim_array(2, 1:NSim, ii);
    pi = sim_array(3, 1:NSim, ii);
    YY4 = [atilde; y; pi]'; 

    % Estimations
    VARMA = VARIrband(VAREst(YY4, p, const), H, 1, Impact);
    A0 = (chol(VARMA.VARVCV,'lower')); 
    B = VARMA.MAcoef;
    AA = squeeze(B(JSneg,:,srhneg{1}))'*A0;
    BB = zeros(size(srhneg{1},2),1);
    g10 = ones(N,1);
    [g1, ~, flag1] = fmincon(@IMP_Obj,g10,AA,BB,[],[],[],[],@cstr, opts); 


    % News shock (zero impact on TFP & max share of TFP variance at long horizon & orthogonal to suprise shock
    flag2 = -10;
    if flag1 >= 1 
        Beq = zeros(2,1);
        Aeq = [g1'; squeeze(B(1,:,1))*A0];
        g20 = [0; randn(N-1,1)];
        [g2, ~, flag2] = fmincon(@MSObj,g20,[],[],Aeq,Beq,[],[],@cstr, opts);

    end

    if flag2 >= 1 & squeeze(B(1,:,H-30:H+1))'*A0*g2 > 0  % makes sure that TFP responds positively to news
        for i = 1:N
            for h = 0:H
                IRSURP(i,h+1,j) = B(i,:,h+1)*A0*g1;
                IRNEWS(i,h+1,j) = B(i,:,h+1)*A0*g2;
            end
        end

        if mod(j,25) == 0
            %clc
            disp(['Bootstrap iteration: ', num2str(round(j*100/R)), '% complete ...'])
        end 

        FEVD(:,:,:,j) = Vardecomp(VARMA, H, [g1 g2]);
        j = j+1;
    elseif flag2 >= 1 & (squeeze(B(1,:,H-30:H+1))'*A0*g2 < 0)  % makes sure that TFP responds positively to news
        g2 = -g2; 
        for i = 1:N
            for h = 0:H
                IRSURP(i,h+1,j) = B(i,:,h+1)*A0*g1;
                IRNEWS(i,h+1,j) = B(i,:,h+1)*A0*g2;
            end
        end


        if mod(j,25) == 0
            %clc
            disp(['Bootstrap iteration: ', num2str(round(j*100/R)), '% complete ...'])
        end 
        
        FEVD(:,:,:,j) = Vardecomp(VARMA, H, [g1 g2]);
        j = j+1;
    end 
        
     ii = ii+1;

end


%%
SIRS_MSSR = prctile(squeeze(IRSURP),[50 100-pct pct],3);
NIRS_MSSR = prctile(squeeze(IRNEWS),[50 100-pct pct],3);

% Forecast Error Variance Decomposition
FEVD_IRS = prctile(squeeze(FEVD),[50 100-pct pct],4);
save(['Sim_data_IRS_MSSR.mat'])





