% This code implements steps 1 and 2 of the bias-corrected boostrap
% interval of Kilian (1998) using the estimate of the bias proposed by
% Pope(1990) and the function ''VARIrbandstep1''

% Input
% VAR: VAR estimates form VAREst
% nbstp: Number of boostrap replications (if nbstp = 0, just 1 bootstrap
% iteration is done; if nbstp = 1, actual data is used to estimate the VAR (no bias correction)))
% Impact: Impact effect of a reduced-form shock (0 for impact increase of
% 1, or 1 for a one std increase on impact
%
% Output (See VAREst for definitions) 
% Out.VARnobs 
% Out.VARlag 
% Out.VARnvars 
% Out.VARcoef 
% Out.Constant 
% Out.VARVCV 
% Out.MAcoef 

% (c) Laurent Kemoe, December 2014

function VARMAir = VARIrband(VAR, Maxhor, nbstp, Impact)
Y = VAR.data;
p = VAR.lag;
const = VAR.Constant;
cst = VAR.Const;
[T,m] = size(Y);
TT = T-p;
Resid1 = VAR.Residuals;
Resid = Resid1 - repmat(mean(Resid1), TT,1);

% Btild = VARIrbandstep1(VAR); % step 1
Btild = VAR.Companion;
Xt_1 = VAR.reg;

% Starting Bootstrap
Btild2 = Btild(1:m,:);
if nbstp == 1
    VARMAir(1) = VARIrf(VAR, Maxhor, Impact);
elseif nbstp == 0
        Ystar = zeros(T,m);
        Ystar(1:p,:) = Y(1:p,:); % presample
        Ystartmp = Xt_1(1,:);
        for i = 1:TT
            Ystar(p+i,:) = cst' + Ystartmp*Btild2' + Resid(ceil(TT*rand),:);
            Ystartmp = [Ystar(p+i,:) Ystartmp(1:end-m)];
        end
        VARtmp = VAREst(Ystar, p, const);

        VARtmp.Companion = VARIrbandstep1(VARtmp);

        VARMAir(1) = VARIrf(VARtmp, Maxhor, Impact);
else    
    
    for j = 1:nbstp
        Ystar = zeros(T,m);
        Ystar(1:p,:) = Y(1:p,:); % presample
        Ystartmp = Xt_1(1,:);
        for i = 1:TT
            Ystar(p+i,:) = cst' + Ystartmp*Btild2' + Resid(ceil(TT*rand),:);
            Ystartmp = [Ystar(p+i,:) Ystartmp(1:end-m)];
        end

        VARtmp = VAREst(Ystar, p, const);

        VARtmp.Companion = VARIrbandstep1(VARtmp);

        VARMAir(j) = VARIrf(VARtmp, Maxhor, Impact);

    end
end

